MdctViaDct4

Struct MdctViaDct4 

pub struct MdctViaDct4<T> { /* private fields */ }
MDCT implementation that converts the problem to a DCT Type 4 of the same size.

It is much easier to express a MDCT as a DCT Type 4 than it is to express it as a FFT, so converting the MDCT to a DCT4 before converting it to a FFT results in greatly simplified code

// Computes a MDCT of input size 1234 via a DCT4, using the MP3 window function
use rustdct::mdct::{Mdct, MdctViaDct4, window_fn};
use rustdct::{DctPlanner, RequiredScratch};

let len = 1234;

let mut planner = DctPlanner::new();
let inner_dct4 = planner.plan_dct4(len);

let dct = MdctViaDct4::new(inner_dct4, window_fn::mp3);

let input = vec![0f32; len * 2];
let (input_a, input_b) = input.split_at(len);
let mut output = vec![0f32; len];
let mut scratch = vec![0f32; dct.get_scratch_len()];

dct.process_mdct_with_scratch(input_a, input_b, &mut output, &mut scratch);

Implementations

Source

impl<T: DctNum> MdctViaDct4<T>

pub fn new<F>(inner_dct: Arc<dyn TransformType4<T>>, window_fn: F) -> Self
where F: FnOnce(usize) -> Vec<T>,

Creates a new MDCT context that will process signals of length inner_dct.len() * 2, with an output of length inner_dct.len()

inner_dct.len() must be even.

window_fn is a function that takes a size and returns a Vec containing size window values. See the window_fn module for provided window functions.